==> atoti_client-0.9.1-py3-none-any.whl: atoti/math/min.py <==
from __future__ import annotations

from .._measure.calculated_measure import CalculatedMeasure, Operator
from .._measure_convertible import MeasureConvertible
from .._measure_description import MeasureDescription, convert_to_measure_description


def min(  # noqa: A001
    *measures: MeasureConvertible,
) -> MeasureDescription:
    """Return a measure equal to the minimum of the passed arguments.

    Example:
        >>> df = pd.DataFrame(
        ...     columns=["City", "A", "B", "C", "D"],
        ...     data=[
        ...         ("Berlin", 15.0, 10.0, 10.1, 1.0),
        ...         ("London", 24.0, 16.0, 20.5, 3.14),
        ...         ("New York", -27.0, 15.0, 30.7, 10.0),
        ...         ("Paris", 0.0, 0.0, 0.0, 0.0),
        ...     ],
        ... )
        >>> table = session.read_pandas(df, keys=["City"], table_name="Math")
        >>> cube = session.create_cube(table)
        >>> l, m = cube.levels, cube.measures
        >>> m["min"] = tt.math.min(m["A.SUM"], m["B.SUM"])
        >>> cube.query(m["A.SUM"], m["B.SUM"], m["min"], levels=[l["City"]])
                   A.SUM  B.SUM     min
        City
        Berlin     15.00  10.00   10.00
        London     24.00  16.00   16.00
        New York  -27.00  15.00  -27.00
        Paris        .00    .00     .00

    """
    if len(measures) <= 1:
        raise ValueError(
            "To find the minimum value of this measure on the levels it is expressed, use `atoti.agg.min()` instead.",
        )

    return CalculatedMeasure(
        Operator(
            "min",
            [convert_to_measure_description(measure) for measure in measures],
        ),
    )

==> atoti_client-0.9.5-py3-none-any.whl: atoti/math/min.py <==
from __future__ import annotations

from .._measure.calculated_measure import CalculatedMeasure, Operator
from .._measure_convertible import MeasureConvertible
from .._measure_description import MeasureDescription, convert_to_measure_description


def min(  # noqa: A001
    *measures: MeasureConvertible,
) -> MeasureDescription:
    """Return a measure equal to the minimum of the passed arguments.

    Example:
        .. doctest::
            :hide:

            >>> session = getfixture("default_session")

        >>> df = pd.DataFrame(
        ...     columns=["City", "A", "B", "C", "D"],
        ...     data=[
        ...         ("Berlin", 15.0, 10.0, 10.1, 1.0),
        ...         ("London", 24.0, 16.0, 20.5, 3.14),
        ...         ("New York", -27.0, 15.0, 30.7, 10.0),
        ...         ("Paris", 0.0, 0.0, 0.0, 0.0),
        ...     ],
        ... )
        >>> table = session.read_pandas(df, keys={"City"}, table_name="Math")
        >>> cube = session.create_cube(table)
        >>> l, m = cube.levels, cube.measures
        >>> m["min"] = tt.math.min(m["A.SUM"], m["B.SUM"])
        >>> cube.query(m["A.SUM"], m["B.SUM"], m["min"], levels=[l["City"]])
                   A.SUM  B.SUM     min
        City
        Berlin     15.00  10.00   10.00
        London     24.00  16.00   16.00
        New York  -27.00  15.00  -27.00
        Paris        .00    .00     .00

    """
    if len(measures) <= 1:
        raise ValueError(
            "To find the minimum value of this measure on the levels it is expressed, use `atoti.agg.min()` instead.",
        )

    return CalculatedMeasure(
        Operator(
            "min",
            [convert_to_measure_description(measure) for measure in measures],
        ),
    )
